@@ -31,7 +31,10 @@ logger = logging.getLogger(__name__)
 # download the content (i.e TemplateURL in cloudformation).
 PARAMFILE_DISABLED = set([
     'api-gateway.put-integration.uri',
-    'apigatewayv2.create-integration.integration-uri',
+    'api-gateway.create-integration.integration-uri',
+    'api-gateway.update-integration.integration-uri',
+    'api-gateway.create-api.target',
+    'api-gateway.update-api.target',
     'appstream.create-stack.redirect-url',
     'appstream.create-stack.feedback-url',
     'appstream.update-stack.redirect-url',
@@ -54,6 +57,7 @@ PARAMFILE_DISABLED = set([
     'custom.deploy.template-file',
 
     'cloudformation.update-stack.stack-policy-during-update-url',
+    'cloudformation.register-type.schema-handler-package',
     # We will want to change the event name to ``s3`` as opposed to
     # custom in the near future along with ``s3`` to ``s3api``.
     'custom.cp.website-redirect',
@@ -73,6 +77,8 @@ PARAMFILE_DISABLED = set([
     'comprehend.detect-sentiment.text',
     'comprehend.batch-detect-sentiment.text-list',
 
+    'emr.create-studio.idp-auth-url',
+
     'iam.create-open-id-connect-provider.url',
 
     'machine-learning.predict.predict-endpoint',
@@ -86,6 +92,11 @@ PARAMFILE_DISABLED = set([
     'rds.copy-db-snapshot.pre-signed-url',
     'rds.create-db-instance-read-replica.pre-signed-url',
 
+    'sagemaker.create-notebook-instance.default-code-repository',
+    'sagemaker.create-notebook-instance.additional-code-repositories',
+    'sagemaker.update-notebook-instance.default-code-repository',
+    'sagemaker.update-notebook-instance.additional-code-repositories',
+
     'serverlessapplicationrepository.create-application.home-page-url',
     'serverlessapplicationrepository.create-application.license-url',
     'serverlessapplicationrepository.create-application.readme-url',
@@ -96,6 +107,11 @@ PARAMFILE_DISABLED = set([
     'serverlessapplicationrepository.update-application.home-page-url',
     'serverlessapplicationrepository.update-application.readme-url',
 
+    'service-catalog.create-product.support-url',
+    'service-catalog.update-product.support-url',
+
+    'ses.put-account-details.website-url',
+
     'sqs.add-permission.queue-url',
     'sqs.change-message-visibility.queue-url',
     'sqs.change-message-visibility-batch.queue-url',
